@@ -130,7 +130,7 @@ void EntityWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
  */
 void EntityWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
-    QDomElement conceptElement = qDoc.createElement("entitywidget");
+    QDomElement conceptElement = qDoc.createElement(QLatin1String("entitywidget"));
     UMLWidget::saveToXMI(qDoc, conceptElement);
     qElement.appendChild(conceptElement);
 }
@@ -189,7 +189,7 @@ void EntityWidget::slotMenuSelection(QAction* action)
 /**
  * Overrides method from UMLWidget.
  */
-QSizeF EntityWidget::minimumSize()
+QSizeF EntityWidget::minimumSize() const
 {
     if (!m_umlObject) {
         return UMLWidget::minimumSize();
@@ -225,11 +225,11 @@ QSizeF EntityWidget::minimumSize()
     //set width to name to start with
     // FIXME spaces to get round beastie with font width,
     // investigate UMLWidget::getFontMetrics()
-    width = getFontMetrics(FT_BOLD_ITALIC).boundingRect(' ' + name() + ' ').width();
-
+    width = getFontMetrics(FT_BOLD_ITALIC).boundingRect(QLatin1Char(' ') + name() +
+                                                        QLatin1Char(' ')).width();
     const int w = getFontMetrics(FT_BOLD).boundingRect(m_umlObject->stereotype(true)).width();
 
-    width = w > width?w:width;
+    width = w > width ? w : width;
 
     UMLClassifier* classifier = (UMLClassifier*)m_umlObject;
     UMLClassifierListItemList list = classifier->getFilteredList(UMLObject::ot_EntityAttribute);
